# This package needs to be run as root and may
# run for a long time, thus we build with full
# hardening. This flags is enabled by default
# on recent Fedora releases, but we need to
# specify it for EPEL <= 7 explicitly.
%global _hardened_build 1


Name:           timeshift
Version:        24.06.5
Release:        %mkrel 2
Summary:        System restore tool for Linux
Group:          Archiving/Backup
License:        GPLv3+ or LGPLv3+
URL:            https://github.com/linuxmint/timeshift
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  meson
BuildRequires:  gettext
BuildRequires:  help2man
BuildRequires:  appstream-util
BuildRequires:  typelib(AppStreamGlib)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  vala

Requires:       cronie
Requires:       hicolor-icon-theme
Requires:       polkit
Requires:       psmisc
Requires:       rsync

# For btrfs systems
Recommends:     btrfs-progs

%description
Timeshift for Linux is an application that provides functionality similar to
the System Restore feature in Windows and the Time Machine tool in Mac OS.
Timeshift protects your system by taking incremental snapshots of the file
system at regular intervals. These snapshots can be restored at a later date
to undo all changes to the system.

In RSYNC mode, snapshots are taken using rsync and hard-links. Common files
are shared between snapshots which saves disk space. Each snapshot is a full
system backup that can be browsed with a file manager.

In BTRFS mode, snapshots are taken using the in-built features of the BTRFS
filesystem. BTRFS snapshots are supported only on BTRFS systems having an
Ubuntu-type subvolume layout (with @ and @home subvolumes).


%prep
%autosetup -p1

# rpmlint
sed -i -e 's|/usr/bin/env bash|/usr/bin/bash|g' src/timeshift-launcher

%build
%meson -Dxapp=false
%meson_build

%install
%meson_install

# Remove duplicate
rm -rf %{buildroot}%{_datadir}/appdata

%find_lang %{name}

%files -f %{name}.lang
%license LICENSES/*
%doc AUTHORS README.md
%{_bindir}/*
%{_metainfodir}/*.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.png
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}-gtk.1.*
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/default.json
%ghost %attr(644, root, root) %{_sysconfdir}/cron.d/%{name}-boot
%ghost %attr(644, root, root) %{_sysconfdir}/cron.d/%{name}-hourly
%ghost %attr(664, root, root) %{_sysconfdir}/%{name}.json


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 24.06.5-2.mga10
+ Revision: 2230878
- Mageia 10 Mass Rebuild

* Thu Dec 05 2024 daviddavid <daviddavid> 24.06.5-1.mga10
+ Revision: 2121732
- new version: 24.06.5

* Wed Dec 04 2024 daviddavid <daviddavid> 24.06.3-1.mga10
+ Revision: 2121520
- new version: 24.06.3

* Thu Jun 27 2024 daviddavid <daviddavid> 24.06.2-1.mga10
+ Revision: 2077391
- new version: 24.06.2

* Tue Mar 05 2024 daviddavid <daviddavid> 24.01.1-1.mga10
+ Revision: 2047579
- new version: 24.01.1

* Tue Dec 05 2023 daviddavid <daviddavid> 23.12.1-1.mga10
+ Revision: 2013435
- new version: 23.12.1

* Mon Oct 09 2023 daviddavid <daviddavid> 23.07.1-2.mga10
+ Revision: 1993770
- dependency libsoup2.4 no more used

* Fri Sep 01 2023 daviddavid <daviddavid> 23.07.1-1.mga10
+ Revision: 1983285
- new version: 23.07.1

* Thu Feb 16 2023 daviddavid <daviddavid> 22.11.2-1.mga9
+ Revision: 1943570
- new version: 22.11.2, to accommodate with glib updates (mga#31563)

* Sun Aug 07 2022 joequant <joequant> 22.06.5-1.mga9
+ Revision: 1875995
- update to 22.06.5

* Thu Mar 31 2022 umeabot <umeabot> 20.03-2.mga9
+ Revision: 1836120
- Mageia 9 Mass Rebuild

* Sun Jun 28 2020 joequant <joequant> 20.03-1.mga8
+ Revision: 1599867
- fix deps
- imported package timeshift

